=========
Functions
=========

The following functions are related to `DataTypeExpr`.

.. currentmodule:: polars
.. autosummary::
   :toctree: api/

   dtype_of
   self_dtype
   DataType.to_dtype_expr
